@@ -23,7 +23,9 @@ REPOS = [
     'brewblox-firmware',
     'brewblox-plaato',
     'brewblox-automation',
+    'brewblox-hass',
     'deployed-images',
+    'node-red-contrib-brewblox',
 ]
 
 
